@@ -1,6 +1,8 @@
-# Copyright 2019 Siemens AG
+# Copyright 2019-2020 Siemens AG
 # SPDX-License-Identifier: MIT
 
+from json.decoder import JSONDecodeError
+
 
 class Error(Exception):
     """Base class for exceptions in this module."""
@@ -23,15 +25,19 @@ class AuthorizationError(Error):
     """Authorization error"""
 
     def __init__(self, description, response):
-        self.message = (
-            f"{description}\n{response.json()['message']} ({response.status_code})"
-        )
+        try:
+            message = response.json().get("message")
+        except JSONDecodeError:
+            message = response.text
+        self.message = f"{description}: {message} ({response.status_code})"
 
 
 class FossologyApiError(Error):
     """Error during a Fossology GET request"""
 
     def __init__(self, description, response):
-        self.message = (
-            f"{description}: '{response.json()['message']}' ({response.status_code})"
-        )
+        try:
+            message = response.json().get("message")
+        except JSONDecodeError:
+            message = response.text
+        self.message = f"{description}: {message} ({response.status_code})"
